/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: advancedoptions.cpp,v 1.6 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <iostream>

#include <qvariant.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qobjectlist.h>
#include <qspinbox.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

#include "advancedoptions.h"

using namespace emotion;

AdvancedOptions::AdvancedOptions( QWidget* parent,  const char* name, WFlags fl )
    : QWidget( parent, name, fl )
{
    if ( !name )
		setName( "AdvancedOptions" );

    QWidget* internalLayout = new QWidget(this);

    _layout = new QHBoxLayout(internalLayout, 0, 6); 

    _index = new QCheckBox(internalLayout);
    _index->setText("Rebuild Index (slows starting)");
    _layout->addWidget( _index );

    _ninocache = new QCheckBox(internalLayout);
    _ninocache->setText("Non-interleaved && No cache");
    _layout->addWidget(_ninocache);

	_volumelabel = new QLabel("Volume boost (may clip): ", internalLayout);
	_volumelabel->setAlignment(AlignRight | AlignVCenter);
	_layout->addWidget(_volumelabel);

	_volume = new QSpinBox(1, 25, 1, internalLayout);
	_volume->setMaximumWidth(48);
	_layout->addWidget(_volume);

	int width = 0;
	int height = _index->height();

	QObjectList *list = queryList("QWidget");
	QObjectListIt it (*list);
	QObject *obj;

	while ((obj = it.current()) != NULL)
	{
		++it;

		QWidget *wid = dynamic_cast<QWidget*>(obj);

		if (wid)
		{
			width += wid->width();
			width += _layout->spacing();
		}
	}

    internalLayout->setGeometry(QRect(0, 0, width, height)); 
	setMinimumSize(width, height);
}

AdvancedOptions::~AdvancedOptions()
{
}

PlayOptions AdvancedOptions::getOptions () const
{
	PlayOptions opts;

	opts.setBool("-idx", _index->state());
	opts.setBool("-forceidx", _index->state());
	opts.setBool("-nocache", _ninocache->state());
	opts.setBool("-ni", _ninocache->state());

	opts.setVolumeBoost(_volume->value());

	return opts;
}
