/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: configuration.cpp,v 1.15 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <fstream>

#include <stdlib.h>

#include "configuration.h"
#include "errormediator.h"

using namespace std;
using namespace emotion;

Configuration::Configuration ()
{
}

Configuration::Configuration (const Configuration &conf)
	: _options(conf._options)
{
}

Configuration::~Configuration ()
{
}

QString Configuration::getString (const QString &key)
{
	QString tmpkey(key.stripWhiteSpace());

	for (const_iterator it=_options.begin();
			it != _options.end();
			it++)
		if (it->first == tmpkey)
			return it->second;

	return QString::null;
}

bool Configuration::getBool (const QString &key)
{
	QString strval = getString (key);

	if (strval == "false" ||
			strval == "off" ||
			strval == "no" ||
			strval == "")
		return false;
	return true;
}

int Configuration::getInt (const QString &key)
{
	QString strval = getString (key);
	bool ok;

	int val = strval.toInt(&ok);

	if (!ok)
		return 0;

	return val;
}

void Configuration::setString (const QString &key, const QString &val)
{
	QString tmpkey(key.stripWhiteSpace()), tmpval(val.stripWhiteSpace());

	if (inList(tmpkey))
	{
		for (iterator it=_options.begin();
				it != _options.end();
				it++)
			if (it->first == tmpkey)
				it->second = tmpval;
	}
	else
		_options.push_back(pair<QString,QString>(tmpkey, tmpval));
}

void Configuration::setBool (const QString &key, const bool val)
{
	QString value;

	if (val != false)
		value = "true";
	else value = "false";

	setString(key, value);
}

void Configuration::setInt (const QString &key, const int val)
{
	QString value;
	value.setNum (val);
	setString(key, value);
}

bool Configuration::inList (const QString &key)
{
	for (const_iterator it=_options.begin();
			it != _options.end();
			it++)
		if (it->first == key)
			return true;
	return false;
}

Configuration::const_iterator Configuration::begin () const
{
	return _options.begin();
}

Configuration::const_iterator Configuration::end () const
{
	return _options.end();
}

Configuration::iterator Configuration::begin ()
{
	return _options.begin();
}

Configuration::iterator Configuration::end ()
{
	return _options.end();
}
