/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: configuration.h,v 1.11 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __CONFIGURATION_H
#define __CONFIGURATION_H

#include <list>
#include <memory>

#include <qstring.h>

using namespace std;

namespace emotion
{
	/** Represents a set of configurable string, int, or bool values associated
	 * with string names. */
	class Configuration
	{
		public:
			virtual ~Configuration ();
			
			virtual QString getString (const QString &key);
			virtual bool getBool (const QString &key);
			virtual int getInt (const QString &key);

			virtual void setString (const QString &key, const QString &val);
			virtual void setBool (const QString &key, const bool val);
			virtual void setInt (const QString &key, const int val);

		protected:
			Configuration ();
			Configuration (const Configuration&);

			typedef list<pair<QString,QString> >::const_iterator const_iterator;
			typedef list<pair<QString,QString> >::iterator iterator;

			const_iterator begin() const;
			const_iterator end() const;

			iterator begin();
			iterator end();

		private:
			list <pair<QString,QString> > _options;

			bool inList (const QString &key);
	};
};

#endif
