/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: controller.h,v 1.14 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __CONTROLLER_H
#define __CONTROLLER_H

#include <qobject.h>

#include "opendialog.h"

class QWidget;

namespace emotion
{
	class MainWindow;
	class Mplayer;
	class PlaylistModel;

	/** The controller part of the MVC trio */
	class Controller
		: public QObject
	{
			Q_OBJECT
		public:
			/** The Controller contains a reference to the model and the view.
			 * It does not own these, and will not delete them. */
			Controller(PlaylistModel *, MainWindow *);
			virtual ~Controller();

			/** Returns true if playlist loop is enabled. */
			virtual bool getLoop() const;

		public slots:
			virtual void actionAdd();
			virtual void actionAddDirectory();
			virtual void actionClear();
			virtual void actionConfiguration();
			virtual void actionConsole();
			virtual void actionDVD();
			virtual void actionForward();
			virtual void actionFullscreen();
			virtual void actionHelp();
			virtual void actionLoop();
			virtual void actionLoop(bool);
			virtual void actionMoveDown();
			virtual void actionMoveUp();
			virtual void actionMute();
			virtual void actionOpen();
			virtual void actionPause();
			virtual void actionPlay();
			virtual void actionPlay(int);
			virtual void actionRemove();
			virtual void actionRewind();
			virtual void actionSeek();
			virtual void actionSeek(int);
			virtual void actionSkipForward();
			virtual void actionSkipBack();
			virtual void actionStop();
			virtual void actionToggleSubs();

			/** Helper function for all of the open file and add file functions
			 * */
			virtual void displayOpenDialog(OpenDialog::Mode mode =
					OpenDialog::ExistingFiles, bool clearlist = false);

		signals:
			/** Signal that is emitted when the value of the loop configuration
			 * option changes */
			virtual void loopToggled(bool);

		private slots:
			/** Used to advance the playlist when mplayer finishes the current
			 * file */
			virtual void mplayerEOF();
			/** Used to advance the playlist when the user skips forward */
			virtual void mplayerKilled();
			/** Used to stop when mplayer is quit by the user */
			virtual void mplayerQuit();
			/** Handle mplayer's printed output */
			virtual void mplayerOutput(const char *);
			virtual void mplayerPercent(int pos);
			/** Used to make sure that playing stops if the current file is
			 * removed from the list */
			virtual void fileRemoved(const vector<int> &);

		private:
			/** Pointer to the view widget; we do not own this, so we do not
			 * allocate/delete it here */
			MainWindow *_view;

			/** Pointer to the model; we do not own this, so we do not
			 * allocate/delete it here */
			PlaylistModel *_model;

			/** Pointer to an Mplayer (used to play all the videos). This we
			 * <b>do</b> own */
			Mplayer *_mplayer;

			/** The currently <b>playing</b> item in the playlist, or -1 if
			 * none. Note that this is only the currently selected file if a
			 * file is playing. */
			int _playingpos;

			/** Whether or not to loop the playlist. */
			bool _loop;
	};
}

#endif
