/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: emotionapp.h,v 1.2 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __EMOTIONAPPLICATION_H
#define __EMOTIONAPPLICATION_H

class QAction;
class QMainWindow;

namespace emotion
{
	class Controller;
	class PlaylistModel;

	/** Top level class contains the model, view, and controller classes and
	 * knows how to construct them so that they work together */
	class emotionApp
	{
		public:
			/** Construct an Application with the given arguments. It is the
			 * clients responsibility to delete the returned pointer.
			 *
			 * This method will create the required model, view, and controller
			 * objects needed to build an Application, and in addition will set
			 * up all signals and slots between them. It will also handle
			 * keyboard shortcuts. */
			static emotionApp *create (int argc, char **argv);

			/** create an application with the specified model, view, and
			 * controller. The application object created takes ownership of
			 * the three pointers and will delete them upon destruction. It is
			 * not recommended that you call this yourself, as creating the MVC
			 * is hard. Instead use the create() method.
			 *
			 * This does not create or register any key shortcuts. */
			emotionApp(PlaylistModel *, QMainWindow *, Controller *);
			~emotionApp();


			/** Display the application */
			void show();

			/** Get a pointer to the view widget */
			QWidget *getView();

		private:
			Controller    *_controller;
			QMainWindow   *_view;
			PlaylistModel *_model;

			/** key command */
			QAction *_actadd;
			/** key command */
			QAction *_actconfiguration;
			/** key command */
			QAction *_actdvd;
			/** key command */
			QAction *_actforward;
			/** key command */
			QAction *_actfullscreen;
			/** key command */
			QAction *_acthelp;
			/** key command */
			QAction *_actloop;
			/** key command */
			QAction *_actmovedown;
			/** key command */
			QAction *_actmoveup;
			/** key command */
			QAction *_actmute;
			/** key command */
			QAction *_actopen;
			/** key command */
			QAction *_actpause;
			/** key command */
			QAction *_actplay;
			/** key command */
			QAction *_actquit;
			/** key command */
			QAction *_actremove;
			/** key command */
			QAction *_actrewind;
			/** key command */
			QAction *_actsubs;
			/** key command */
			QAction *_actskipback;
			/** key command */
			QAction *_actskipforward;
			/** key command */
			QAction *_actstop;
			/** key command */
			QAction *_actvolumeup;
			/** key command */
			QAction *_actvolumedown;
	};
};

#endif
