/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: errormediator.cpp,v 1.6 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <iostream>
#include <list>
#include <memory>

#include "errormediator.h"
#include "exception.h"

using namespace emotion;

auto_ptr<ErrorMediator> ErrorMediator::_instance;

ErrorMediator::ErrorMediator ()
	: _acceptor (NULL)
{
}

ErrorMediator *ErrorMediator::instance ()
{
	if (_instance.get() == NULL)
		_instance.reset (new ErrorMediator ());
	return _instance.get();
}

void ErrorMediator::submitError (const Exception &e)
{
	if (_acceptor)
	{
		_acceptor->acceptError (e);

		return;
	}

	cerr << "ErrorMediator: warning: no accoptor set" << endl;
	cerr << "Error: " << e.getMessage() << endl;

	_errors.push_back (e.getMessage());
}

void ErrorMediator::setAcceptor (Acceptor *a)
{
	_acceptor = a;

	/* erase pending errors */
	for (list<QString>::const_iterator it=_errors.begin();
			it!=_errors.end();
			it++)
		_acceptor->acceptError(Exception(*it));
	_errors.clear ();
}
