/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: errormediator.h,v 1.6 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __ERRORMEDIATOR_H
#define __ERRORMEDIATOR_H

#include <list>
#include <memory>

#include "exception.h"

using namespace std;

namespace emotion
{
	class Acceptor;

	/** Global class that makes sure errors get reported. It accepts errors and
	 * passes them to an Acceptor if one exists, and otherwise stores the
	 * messages (reporting them to the Acceptor when it gets set) */
	class ErrorMediator
	{
		public:
			/** get a pointer to the one mediator */
			static ErrorMediator *instance ();

			/** report that an error occured */
			void submitError (const Exception &e);

			/** set the acceptor who wants to handle the errors */
			void setAcceptor (Acceptor *);

		private:
			/** ErrorMediator is a singleton */
			ErrorMediator ();
			static auto_ptr <ErrorMediator> _instance;

			/** A pointer to the current Acceptor, and null if not set */
			Acceptor *_acceptor;
			/** Where errors are queued up if there is no Acceptor to handle
			 * them */
			list <QString> _errors;
	};

	/** Interface representing a class that can handle errors */
	class Acceptor 
	{
		public:
			/** Called when an error occurs */
			virtual void acceptError (const Exception &e) = 0;
	};
}

#endif
