/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: fileconfiguration.cpp,v 1.2 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <fstream>

#include "errormediator.h"
#include "fileconfiguration.h"

using namespace emotion;

FileConfiguration::FileConfiguration (const QString &filename)
	: _filename (filename)
{
	ifstream cfg (_filename.ascii());

	if (!cfg)
	{
		// Who cares?
		/*QString msg;
		msg += "Unable to open configuration file '";
		msg += cfgfile + "'.";
		ErrorMediator::instance()->submitError( Exception ( msg ) );*/
	}
	else
	{
		while (!cfg.eof())
		{
			char charbuf[4096];
			cfg.getline (charbuf, 4096);

			QString buffer (charbuf);
			buffer = buffer.stripWhiteSpace ();

			/* skip blanks and comments */
			if (buffer.length() == 0)
				continue;
			if (buffer.startsWith("#"))
				continue;

			QString key, value;
			key = buffer.section('=', 0, 0);
			value = buffer.section('=', 1);

			setString (key, value);
		}
	
		cfg.close ();
	}
}

FileConfiguration::~FileConfiguration()
{
	write ();
}

void FileConfiguration::write ()
{
	ofstream cfg (_filename.ascii());

	if (!cfg)
	{
		QString msg;
		msg += "Unable to open configuration file '";
		msg += _filename + "' for writing.";
		ErrorMediator::instance()->submitError( Exception ( msg ) );
		return;
	}

	for (const_iterator it=begin();
			it != end();
			it++)
		cfg << it->first << " = " << it->second << endl;

	cfg.close ();
}

QString FileConfiguration::getFilename () const
{
	return _filename;
}
