/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: iconset.cpp,v 1.3 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <cassert>

#include <qpixmap.h>

#include "iconset.h"

using namespace emotion;

IconSet::IconSet(const char *normal, const char *active, const char *down)
{
	memset(_pixmaps, 0, sizeof(QPixmap*) * NUMTOGGLESTATES * NUMTOGGLESTATES);

	for (int i=0; i<NUMTOGGLESTATES; i++)
		copyToState(i, QPixmap(normal), QPixmap(active), QPixmap(down));
}

IconSet::IconSet(const QPixmap &normal, const QPixmap &active, const QPixmap &down)
{
	memset(_pixmaps, 0, sizeof(QPixmap*) * NUMTOGGLESTATES * NUMTOGGLESTATES);

	for (int i=0; i<NUMTOGGLESTATES; i++)
		copyToState(i, normal, active, down);
}

IconSet::IconSet(const IconSet &off, const IconSet &on)
{
	memset(_pixmaps, 0, sizeof(QPixmap*) * NUMTOGGLESTATES * NUMTOGGLESTATES);

	copyToState(OFF, off.getPixmap(NORMAL, OFF), off.getPixmap(ACTIVE, OFF),
			off.getPixmap(DOWN, OFF));
	copyToState(ON, on.getPixmap(NORMAL, ON), on.getPixmap(ACTIVE, ON),
			on.getPixmap(DOWN, ON));
}

IconSet::IconSet(const IconSet &set)
{
	memset(_pixmaps, 0, sizeof(QPixmap*) * NUMTOGGLESTATES * NUMTOGGLESTATES);

	for (int i=0; i<NUMTOGGLESTATES; i++)
		for (int j=0; j<NUMBUTTONSTATES; j++)
			_pixmaps[i][j] = new QPixmap(set.getPixmap(j,i));
}

IconSet::~IconSet()
{
	for (int i=0; i<NUMTOGGLESTATES; i++)
		for (int j=0; j<NUMBUTTONSTATES; j++)
			delete _pixmaps[i][j];
}

void IconSet::copyToState(int state, const QPixmap &normal, const QPixmap
		&active, const QPixmap &down)
{
	_pixmaps[state][NORMAL] = new QPixmap(normal);
	_pixmaps[state][ACTIVE] = new QPixmap(active);
	_pixmaps[state][DOWN] = new QPixmap(down);
}

QPixmap IconSet::getPixmap(const int buttonstate, const int togglestate) const
{
	assert(_pixmaps[togglestate][buttonstate] != NULL);
	return *_pixmaps[togglestate][buttonstate];
}
