/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: imagebutton.h,v 1.10 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __IMAGEBUTTON_H
#define __IMAGEBUTTON_H

#include <qbutton.h>
#include <qtimer.h>

#include "iconset.h"

class QPopupMenu;

namespace emotion
{
	/** A button class that allows any-size icons. Similar to the QPushButton class. */
	class ImageButton
		: public QButton
	{
		Q_OBJECT
		public:
			ImageButton (QWidget *parent, const IconSet &);

			virtual ~ImageButton ();

			virtual void setPopup (QPopupMenu *popup);
			virtual void setPopupDelay (int millis);

			virtual bool autoRaise () const;
			virtual void setAutoRaise (const bool );

			virtual void setToggleButton(bool);

		public slots:
			virtual void flash ();
			virtual void setOn(bool);

		protected:
			virtual void drawButton (QPainter *);

		protected slots:
			virtual void pressed ();
			virtual void released ();

			virtual void enterEvent (QEvent *);
			virtual void leaveEvent (QEvent *);

			virtual void popup ();

			virtual void aboutToShowMenu ();
			virtual void aboutToHideMenu ();

			virtual void toggledStateChanged(bool state);

		private:
			void init ();

			IconSet _icons;

			QPopupMenu *_popup;
			bool _menudisplayed;
			int _delay;

			QTimer _menutimer;

			bool _autoraise;

			enum {
				MOUSEOVER = 1,
				DOWN = 2
			};
			int _buttonstate;

			enum {
				NORMAL,
				TOGGLED
			};
			int _togglestate;
		
		private slots:
			void displayMenu ();
	};
}

#endif
