/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: mainwindow.cpp,v 1.55 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <qapplication.h>
#include <qerrormessage.h>
#include <qfiledialog.h>
#include <qhbox.h>
#include <qlabel.h>
#include <qmainwindow.h>
#include <qpopupmenu.h>
#include <qslider.h>
#include <qstatusbar.h>
#include <qtoolbar.h>
#include <qtooltip.h>
#include <qvbox.h>
#include <qwhatsthis.h>

#include "aboutdialog.h"
#include "consoledialog.h"
#include "icons.h"
#include "iconset.h"
#include "mainwindow.h"
#include "mixer.h"
#include "optionsdialog.h"
#include "version.h"

using namespace emotion;

MainWindow::MainWindow (QWidget *parent, const char *name)
	: QMainWindow (parent, name)
{
	_toolbar = new QToolBar(this);
	_vlayout = new QVBox(this);
	_buttonbar = new QHBox(_vlayout);
	_seekspacer1 = new QLabel(_vlayout);
	_seek = new QSlider(0, 100, 1, 0, Qt::Horizontal, _vlayout);
	_seekspacer2 = new QLabel(_vlayout);
	_playlist = new Playlist(this, _vlayout);
	_menubutton = new ImageButton(_toolbar, IconSet(emotionIcons::menu_1,
			emotionIcons::menu_2, emotionIcons::menu_3));
	_menu = new QPopupMenu(_menubutton);
	_open = new ImageButton(_toolbar, IconSet(emotionIcons::open_1,
			emotionIcons::open_2, emotionIcons::open_3));
	_dvd = new ImageButton(_toolbar, IconSet(emotionIcons::dvd_1,
			emotionIcons::dvd_2, emotionIcons::dvd_3));
	_options = new ImageButton(_toolbar, IconSet(emotionIcons::configure_1,
			emotionIcons::configure_2, emotionIcons::configure_3));
	_help = new ImageButton(_toolbar, IconSet(emotionIcons::help_1,
			emotionIcons::help_2, emotionIcons::help_3));
	_quit = new ImageButton(_toolbar, IconSet(emotionIcons::exit_1,
			emotionIcons::exit_2, emotionIcons::exit_3));
	_toolbarspacer = new QLabel(_toolbar);
	_controls = new QToolBar("Player Controls", this, _buttonbar);
	_skipback = new ImageButton(_controls, IconSet(emotionIcons::skipback_1,
			emotionIcons::skipback_2, emotionIcons::skipback_3));
	_back = new ImageButton(_controls, IconSet(emotionIcons::rewind_1,
			emotionIcons::rewind_2, emotionIcons::rewind_3));
	_stop = new ImageButton(_controls, IconSet(emotionIcons::stop_1,
			emotionIcons::stop_2, emotionIcons::stop_3));
	_pause = new ImageButton(_controls, IconSet(emotionIcons::pause_1,
			emotionIcons::pause_2, emotionIcons::pause_3));
	_play = new ImageButton(_controls, IconSet(emotionIcons::play_1,
			emotionIcons::play_2, emotionIcons::play_3));
	_forward = new ImageButton(_controls, IconSet(emotionIcons::fastforward_1,
			emotionIcons::fastforward_2, emotionIcons::fastforward_3));
	_skipforward = new ImageButton(_controls, IconSet(emotionIcons::skipforward_1,
			emotionIcons::skipforward_2, emotionIcons::skipforward_3));
	_controlspacer = new QLabel(_controls);
	_subs = new ImageButton(_controls, IconSet(IconSet(emotionIcons::subtitles_1,
					emotionIcons::subtitles_2, emotionIcons::subtitles_3),
				IconSet(emotionIcons::nosubtitles_1, emotionIcons::nosubtitles_2,
					emotionIcons::nosubtitles_3)));
	_fullscreen = new ImageButton(_controls, IconSet(emotionIcons::fullscreen_1,
			emotionIcons::fullscreen_2, emotionIcons::fullscreen_3));
	_mute = new ImageButton(_controls, IconSet(IconSet(emotionIcons::volume_1,
					emotionIcons::volume_2, emotionIcons::volume_3),
				IconSet(emotionIcons::mute_1, emotionIcons::mute_2,
					emotionIcons::mute_3)));
	_volume = new QSlider(0, 100, 1, Mixer::instance()->getVolume(), Qt::Horizontal, _controls);
	_console = new ConsoleDialog(this);
	_errordlg = new QErrorMessage(this);

	_mute->setToggleButton(TRUE);
	_subs->setToggleButton(TRUE);

	_controls->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
				QSizePolicy::Maximum));

	setCentralWidget (_vlayout);
	statusBar()->message("Welcome to eMotion: " VERSIONSTRING);

	QToolTip::add(_menubutton, "Menu");
	QWhatsThis::add(_menubutton, "Opens the main menu");
	QToolTip::add(_open, "[Control-O] Open");
	QWhatsThis::add(_open, "Open existing files and clear the playlist");
	QToolTip::add(_dvd, "[Control-D] Play DVD");
	QWhatsThis::add(_dvd, "Clear the playlist and replace it with a DVD title");
	QToolTip::add(_options, "[Control-P] Configure eMotion");
	QWhatsThis::add(_options, "Configure options, such as the MPlayer location");
	QToolTip::add(_quit, "[Control-Q] Quit");
	QWhatsThis::add(_quit, "Quit");
	QToolTip::add(_help, "[F1] What's This?");
	QWhatsThis::add(_help, "Help. You can also get help by pressing F1");

	QToolTip::add(_skipback, "[Page Up] Previous File");
	QWhatsThis::add(_skipback, "Select the previous file in the playlist");
	QToolTip::add(_back, "[Left Arrow] Rewind");
	QWhatsThis::add(_back, "Rewind the currently playing video a few seconds");
	QToolTip::add(_stop, "[S] Stop");
	QWhatsThis::add(_stop, "Stop the currently playing video");
	QToolTip::add(_pause, "[Space] Pause");
	QWhatsThis::add(_pause, "Pause the currently playing video");
	QToolTip::add(_play, "[P] Play");
	QWhatsThis::add(_play, "Stop any currently playing video and "
			"start playing the currently selected one");
	QToolTip::add(_forward, "[Right Arrow] Fast Forward");
	QWhatsThis::add(_forward, "Fast forward the currently playing video a few seconds");
	QToolTip::add(_skipforward, "[Page Down] Next File");
	QWhatsThis::add(_skipforward, "Select the next file in the playlist");
	QToolTip::add(_subs, "[Control-S] Toggle Subtitles");
	QWhatsThis::add(_subs, "Enable or disable display of subtitles for the "
			"currently playing video, if subtitles exist for it");
	QToolTip::add(_fullscreen, "[f] Toggle Fullscreen");
	QWhatsThis::add(_fullscreen, "Enable or disable full screen playback of the "
			"currently playing video");
	QToolTip::add(_mute, "[Control-M] Toggle Mute");
	QWhatsThis::add(_mute, "Mute this comuputer's audio playback");
	QToolTip::add(_volume, "[Up/Down Arrows] Adjust Volume");
	QWhatsThis::add(_volume, "Slide this bar to increase and decrease the "
			"audio volume on this computer");

	_volume->setMinimumWidth(8);
	_volume->setMaximumWidth(72);
	_volume->setMinimumHeight(4);
	_volume->setMaximumHeight(12);

	_seek->setTracking(FALSE);
	_seek->setDisabled(TRUE);
	_seek->setMinimumHeight(12);
	_seekspacer1->setMaximumHeight(4);
	_seekspacer2->setMaximumHeight(4);

	_toolbar->setStretchableWidget (_toolbarspacer);
	_controls->setStretchableWidget (_controlspacer);

	_play->setFocus ();

	_back->setAutoRepeat(TRUE);
	_forward->setAutoRepeat(TRUE);

	_menubutton->setPopup (_menu);

	QObject::connect(_playlist, SIGNAL(fileClicked(int)), this,
			SLOT(listFileClicked(int)));
}

MainWindow::~MainWindow ()
{
	// All the widgets are deleted by Qt automatically

	hide();
}

void MainWindow::show ()
{
	/* call parent class's show, so that the window still shows up */
	QMainWindow::show ();
	
	/* after visible, register to accept errors. This way, all errors will be
	 * reported only after a GUI exists in which to display them */
	ErrorMediator::instance()->setAcceptor (this);
}

void MainWindow::acceptError (const Exception &e)
{
	_errordlg->message (e.getMessage ());
}

void MainWindow::about ()
{
	AboutDialog about (this, "About", TRUE);
	about.exec ();
}

ImageButton *MainWindow::getQuit()
{
	return _quit;
}

ImageButton *MainWindow::getOpen()
{
	return _open;
}

QPopupMenu *MainWindow::getMenu()
{
	return _menu;
}

void MainWindow::modelFileAdded(const vector<QString> &files, int pos)
{
	_playlist->fileAdded(files, pos);
}

void MainWindow::modelFileRemoved(const vector<int> &files)
{
	_playlist->fileRemoved(files);
}

ImageButton *MainWindow::getAdd()
{
	return _playlist->getAdd();
}

ImageButton *MainWindow::getRemove()
{
	return _playlist->getRemove();
}

QSlider *MainWindow::getVolumeSlider()
{
	return _volume;
}

vector<int> MainWindow::getSelection() const
{
	return _playlist->getSelection();
}

void MainWindow::volumeChanged (int vol)
{
	_volume->setValue(vol);
}

ImageButton *MainWindow::getPlaylistDown()
{
	return _playlist->getDown();
}

void MainWindow::setSelection(const vector<int> &rows)
{
	_playlist->setSelection(rows);
}

void MainWindow::modelFileSwapped(int i, int j)
{
	_playlist->fileSwapped(i, j);
}

ImageButton *MainWindow::getConfiguration()
{
	return _options;
}

ImageButton *MainWindow::getMute()
{
	return _mute;
}

QPopupMenu *MainWindow::getAddMenu()
{
	return _playlist->getAddMenu();
}

ImageButton *MainWindow::getPlaylistUp()
{
	return _playlist->getUp();
}

ImageButton *MainWindow::getSkipForward()
{
	return _skipforward;
}

void MainWindow::modelFileSelected(int i)
{
	_playlist->fileSelected(i);
}

void MainWindow::modelFileDeselected(int i)
{
	_playlist->fileDeselected(i);
}

ImageButton *MainWindow::getSkipBack()
{
	return _skipback;
}

ImageButton *MainWindow::getPlay()
{
	return _play;
}

ImageButton *MainWindow::getStop()
{
	return _stop;
}

void MainWindow::listFileClicked(int row)
{
	emit fileClicked(row);
}

ImageButton *MainWindow::getRewind()
{
	return _back;
}

ImageButton *MainWindow::getForward()
{
	return _forward;
}

ImageButton *MainWindow::getPause()
{
	return _pause;
}

ImageButton *MainWindow::getFullscreen()
{
	return _fullscreen;
}

ImageButton *MainWindow::getSubs()
{
	return _subs;
}

ImageButton *MainWindow::getLoop()
{
	return _playlist->getLoop();
}

QPopupMenu *MainWindow::getRemoveMenu()
{
	return _playlist->getRemoveMenu();
}

ImageButton *MainWindow::getHelp()
{
	return _help;
}

ImageButton *MainWindow::getDVD()
{
	return _dvd;
}

void MainWindow::modelOutput(const QString &out)
{
	_console->append(out);
}

void MainWindow::showConsole()
{
	_console->show();
}

void MainWindow::displayPosition (int percent)
{
	_seek->setValue(percent);
}

void MainWindow::disablePosition()
{
	displayPosition(0);
	_seek->setDisabled(TRUE);
}

void MainWindow::enablePosition()
{
	_seek->setDisabled(FALSE);
}

QSlider *MainWindow::getSeekSlider ()
{
	return _seek;
}
