/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: mixer.h,v 1.9 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __MIXER_H
#define __MIXER_H

#include <memory>

#include <qobject.h>
#include <qtimer.h>

using namespace std;

namespace emotion
{
	/** Access to the audio mixer device */
	class Mixer : public QObject
	{
			Q_OBJECT
		public:
			static Mixer *instance ();
			virtual ~Mixer ();

			virtual int getVolume() const;
			virtual int getStep () const;
			virtual void setStep (int s);

			virtual bool isMuted() const;

		public slots:
			virtual void setVolume (int v);

			virtual void incVolume ();
			virtual void decVolume ();
			virtual void checkVolume ();
			void toggleMute ();

		signals:
			virtual void volumeChanged (int v);
			virtual void muted (bool);

		private:
			Mixer (bool log = false);

			int _lastvolume;
			bool _log;
			int _mixerfd;
			int _step;
			QTimer _timer;

			bool _muted;
			int _oldvol;

			static auto_ptr<Mixer> _instance;
	};
}

#endif
