/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: mplayerfile.cpp,v 1.3 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <qfile.h>
#include <qstring.h>
#include <qregexp.h>

#include "globalconfiguration.h"
#include "mplayerfile.h"
#include "playoptions.h"

using namespace emotion;

MplayerFile::MplayerFile(const QString &file, const PlayOptions &options)
	: _options(options)
{
	/* get the name without leading path (/home/foo/x.avi -> x.avi) */
	_name = file.section ('/', -1);
	_name.stripWhiteSpace();
	if (_name.length() == 0 || file.startsWith("dvd://"))
		_name = file;

	_absname = file;

	/* get the name w/o extension (x.avi -> x) */
	QString extregex(GlobalConfiguration::instance()->getString("extensionmatch"));
	_name.replace (QRegExp(extregex), "");
}

MplayerFile::MplayerFile(const MplayerFile &file)
	: _name(file._name),
	_absname(file._absname),
	_options(file._options)
{
}

MplayerFile::~MplayerFile()
{
}

QString MplayerFile::getName() const
{
	return _name;
}

void MplayerFile::setName(const QString &name)
{
	_name = name;
}

QString MplayerFile::getPath() const
{
	return _absname;
}

PlayOptions MplayerFile::getOptions() const
{
	return _options;
}
