/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: opendialog.cpp,v 1.5 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <vector>

#include <qfiledialog.h>

#include "advancedoptions.h"
#include "globalconfiguration.h"
#include "opendialog.h"

using namespace emotion;

OpenDialog::OpenDialog(QWidget *parent, const char *name, bool modal, WFlags f)
	: QFileDialog (parent, name, modal)
{
	/* Create the special options panel */
	_advopts = new AdvancedOptions(this);
	resize (width(), height() + _advopts->height());
	addWidgets (NULL, _advopts, NULL);

	/* Set the directory to the last accessed */
	QString dir ( GlobalConfiguration::instance()->getString("directory") );
	if (dir == "")
		dir = QString::null;
	setDir(dir);
}

OpenDialog::~OpenDialog()
{
	delete _advopts;
}

void OpenDialog::accept()
{
	/* Save the currently selected directory so we can start here next time */
	GlobalConfiguration::instance()->setString("directory",
			dir()->absPath());

	QFileDialog::accept();
}

QString OpenDialog::selectedFile() const
{
	return QFileDialog::selectedFile();
}

QStringList OpenDialog::selectedFiles() const
{
	return QFileDialog::selectedFiles();
}

vector <MplayerFile> OpenDialog::selectedItems() const
{
	QStringList filenames;
	
	if (mode() == DirectoryOnly)
		filenames.push_back(selectedFile());
	else
		filenames = selectedFiles();

	vector <MplayerFile> files;

	for (QStringList::const_iterator it = filenames.begin();
			it != filenames.end();
			it++)
		addFileOrDir(files, *it);

	return files;
}

void OpenDialog::addFileOrDir(vector <MplayerFile> &files, const QString &filename) const
{
	if (isDir(filename))
		addDirectory(files, filename);
	else
		files.push_back(MplayerFile(filename, _advopts->getOptions()));
}

bool OpenDialog::isDir(const QString &filename)
{
	QFileInfo finfo (filename);

	return finfo.exists() && finfo.isDir();
}

void OpenDialog::addDirectory(vector <MplayerFile> &files, const QString &dirpath) const
{
	QDir dir(dirpath);
	QStringList contents (dir.entryList());

	for (QStringList::const_iterator it = contents.begin();
			it != contents.end();
			it++)
	{
		if (*it == "." || *it == "..")
			continue;

		QString abspath (dir.filePath(*it));

		QFileInfo finfo(abspath);

		if (finfo.isDir())
			addDirectory(files, abspath);
		else
		{
			files.push_back (MplayerFile(abspath, _advopts->getOptions()));
		}
	}
}
