/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: opendialog.h,v 1.5 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __OPENDIALOG_H
#define __OPENDIALOG_H

#include <vector>

#include <qfiledialog.h>
#include <qstring.h>
#include <qstringlist.h>

#include "mplayerfile.h"

namespace emotion
{
	class AdvancedOptions;

	/** A dialog box class that displays a file chooser with some
	 * mplayer-specific options on it */
	class OpenDialog
		: public QFileDialog
	{
		Q_OBJECT
		public:
			OpenDialog(QWidget *parent=0, const char *name=0, bool modal=FALSE, WFlags f=0);
			virtual ~OpenDialog ();

			/** Returns MplayerFile objects, one for each file selected. If a
			 * directory was selected, its contents are recursively processed.
			 * */
			vector <MplayerFile> selectedItems() const;

		public slots:
			void accept();

		protected slots:
		protected:
			static bool isDir (const QString &file);
		
		private:
			AdvancedOptions *_advopts;

			QString selectedFile() const;
			QStringList selectedFiles() const;

			void addFileOrDir(vector <MplayerFile> &files, const QString &filename) const;
			void addDirectory(vector <MplayerFile> &, const QString &file) const;
	};
}

#endif
