/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: optionsdialog.cpp,v 1.13 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <qfiledialog.h>

#include "globalconfiguration.h"
#include "optionsdialog.h"

using namespace emotion;

OptionsDialog::OptionsDialog(QWidget *parent, const char *name, bool modal, WFlags f)
	: QDialog (parent, name, modal, f),
	_grid(this),
	_buttonbar(this),
	_mplayerlabel ("Mplayer Location:", this),
	_mplayeredit (this),
	_mplayerbrowse ("&Browse...", this),
	_mixerlabel ("Mixer Device:", this),
	_mixeredit (this),
	_fullscreen("&Full Screen", this),
	_aolabel ("Audio output driver:", this),
	_aoedit (this),
	_displaylabel ("X Display:", this),
	_displayedit (this),
	_cancel ("&Cancel", &_buttonbar),
	_ok ("&Ok", &_buttonbar)
{
	_grid.expand (5, 3);
	_grid.setMargin (6);
	_grid.setSpacing (6);

	int lrow = 0;
	int rrow = 0;

	_grid.addWidget (&_mplayerlabel, lrow, 0);
	_grid.addWidget (&_mplayeredit, lrow, 1);
	_grid.addWidget (&_mplayerbrowse, rrow, 2);
	lrow++;
	rrow++;

	_grid.addWidget (&_mixerlabel, lrow, 0);
	_grid.addWidget (&_mixeredit, lrow, 1);
	lrow++;

	_grid.addWidget (&_fullscreen, rrow, 2);
	rrow++;

	_grid.addWidget (&_aolabel, lrow, 0);
	_grid.addWidget (&_aoedit, lrow, 1);
	lrow++;

	_grid.addWidget (&_displaylabel, lrow, 0);
	_grid.addWidget (&_displayedit, lrow, 1);
	lrow++;

	_grid.addMultiCellWidget (&_buttonbar, _grid.numRows()-1,
			_grid.numRows()-1, 0, _grid.numCols()-1, AlignRight);

	_ok.setAutoDefault (TRUE);
	_ok.setDefault (TRUE);

	QObject::connect (&_mplayerbrowse, SIGNAL(clicked()), this, SLOT(browseMplayer()));

	QObject::connect (&_cancel, SIGNAL(clicked()), this, SLOT(reject()));
	QObject::connect (&_ok, SIGNAL(clicked()), this, SLOT(accept()));

	updateDisplay ();
}

OptionsDialog::~OptionsDialog()
{
}

void OptionsDialog::browseMplayer()
{
	QFileDialog fd (this);
	fd.setMode(QFileDialog::ExistingFile);
	fd.setCaption ("Select Mplayer");

	if (fd.exec() != QDialog::Accepted)
		return;

	QString mplayer (fd.selectedFile());

	_mplayeredit.setText (mplayer);
}

void OptionsDialog::updateDisplay ()
{
	GlobalConfiguration *conf = GlobalConfiguration::instance ();

	_mplayeredit.setText (conf->getString("mplayer"));
	_mixeredit.setText (conf->getString("mixer"));
	_aoedit.setText (conf->getString("audioout"));
	_displayedit.setText (conf->getString("display"));
	_fullscreen.setChecked (conf->getBool("fullscreen"));
}

void OptionsDialog::accept ()
{
	GlobalConfiguration *conf = GlobalConfiguration::instance ();

	conf->setString	("mplayer", _mplayeredit.text());
	conf->setString	("mixer", _mixeredit.text());
	conf->setString	("audioout", _aoedit.text());
	conf->setString	("display", _displayedit.text());
	conf->setBool	("fullscreen", _fullscreen.isChecked());

	conf->write ();
	
	QDialog::accept ();
}
