/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: playlist.h,v 1.24 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __PLAYLIST_H
#define __PLAYLIST_H

#include <vector>

#include <qframe.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qpopupmenu.h>
#include <qtable.h>
#include <qtoolbar.h>
#include <qvbox.h>

#include "imagebutton.h"

class QMainWindow;

using namespace std;

namespace emotion
{
	/** Playlist gui widget */
	class Playlist : public QFrame
	{
			Q_OBJECT
		public:
			Playlist (QMainWindow *mainwin, QWidget *parent = 0, const char
					*name = 0, WFlags f = 0);
			virtual ~Playlist ();

			virtual ImageButton *getAdd();
			virtual QPopupMenu  *getAddMenu();
			virtual ImageButton *getDown();
			virtual ImageButton *getLoop();
			virtual ImageButton *getRemove();
			virtual QPopupMenu  *getRemoveMenu();
			virtual ImageButton *getUp();

			virtual vector<int> getSelection() const;
			virtual void setSelection(const vector<int>&);

		public slots:
			/** Called when the PlaylistModel changes so that this view stays
			 * up to date */
			virtual void fileAdded(const vector<QString> &, int);
			/** Called when the PlaylistModel changes so that this view stays
			 * up to date */
			virtual void fileRemoved(const vector<int> &);
			/** Called when the PlaylistModel changes so that this view stays
			 * up to date */
			virtual void fileSwapped(int, int);
			/** Called when the PlaylistModel changes so that this view stays
			 * up to date */
			virtual void fileDeselected(int);
			/** Called when the PlaylistModel changes so that this view stays
			 * up to date */
			virtual void fileSelected(int);

			/** Called when the user double-clicks an item in the playlist.
			 * This signal is forwarded to the MainWindow class */
			virtual void listItemClicked(int, int, int, const QPoint&);

		signals:
			/** see listItemClicked() above */
			virtual void fileClicked(int);

		private:
			QVBox       _vbox;
			QVBoxLayout _vlayout;

			QTable      _list;

			QToolBar    _buttonbar;
			ImageButton _addfile;
			QPopupMenu  _addfilemenu;
			ImageButton _rmfile;
			QPopupMenu  _rmfilemenu;
			QLabel      _spacer;
			ImageButton _loop;
			ImageButton _up;
			ImageButton _down;
	};
}

#endif
