/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: playlistmodel.h,v 1.6 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __PLAYLISTMODEL_H
#define __PLAYLISTMODEL_H

#include <qobject.h>
#include <qstring.h>

#include "mplayerfile.h"

namespace emotion
{
	/** the model object (MVC-style) */
	class PlaylistModel
		: public QObject
	{
			Q_OBJECT
		public:
			PlaylistModel();
			virtual ~PlaylistModel();

			/** Add the provided MplayerFiles to the end of the playlist */
			virtual void add(const vector <MplayerFile> &files);
			/** Remove the specified indexes from the playlist */
			virtual void remove(const vector <int> &positions);

			/** Skip forward by one in the list */
			virtual void advance();
			/** Skip back by one in the list */
			virtual void retreat();

			/** Get the size of the playlist */
			virtual int size() const;

			/** swap the specified indexes in the playlist */
			virtual void swap(int i, int j);

			/** Get the file at the specified index */
			virtual MplayerFile *get(int i);
			/** get the current playlist position */
			virtual int getPosition() const;

			/** set the current playlist position */
			virtual void setPosition(int);

			/** empty the playlist */
			virtual void clear();

			/** returns true if the playlist is empty */
			virtual bool empty() const;

		public slots:
			/** read a 1-file per line playlist file from the specified
			 * filename */
			virtual void read(const QString &);
			/** write a 1-file per line playlist to the specified filename */
			virtual void write(const QString &) const;
			
		signals:
			/** Emitted when files are inserted into the list starting at the
			 * spefied position */
			void fileAdded(const vector<QString> &file, int pos);
			/** Emitted when files are removed from the list */
			void fileRemoved(const vector<int> &pos);
			/** Emitted when files are swapped */
			void fileSwapped(int i, int j);

			/** Emitted when the playlist position leaves the specified entry
			 * */
			void fileDeselected(int i);
			/** Emitted when the playlist position is set to the specified
			 * position */
			void fileSelected(int i);

		private:
			typedef vector<MplayerFile>::iterator iterator;
			typedef vector<MplayerFile>::const_iterator const_iterator;

			vector <MplayerFile> _list;
			int _position;
	};
}

#endif
