/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: playoptions.h,v 1.4 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#ifndef __PLAYOPTIONS_H
#define __PLAYOPTIONS_H

#include <vector>

#include "configuration.h"

namespace emotion
{
	/** Represents a set of options that will affect how mplayer plays a file.
	 * These options correspond to command line arguments */
	class PlayOptions
		: public Configuration
	{
		public:
			PlayOptions();
			PlayOptions(const PlayOptions &);
			~PlayOptions ();

			/** Returns a vector of command line options for mplayer that
			 * represent all the options in this object, except for volume
			 * boost (see below) */
			vector<QString> getOptionStrings () const;

			void setVolumeBoost(const int );
			int getVolumeBoost() const;

		private:
			/** Volume boost is stored seperately from the other options
			 * because it has a different command line format, so I just handle
			 * it as a special case for now. */
			int _volboost;
	};
}

#endif
