/*
 * The author disclaims copyright to the included source code. It is placed in
 * the public domain. In place of a lengthy legal notice, here is a blessing:
 *
 * 	May you do good and not evil.
 * 	May you find forgiveness for yourself and forgive others.
 * 	May you share freely, never taking more than you give.
 *
 * $Id: sighandler.cpp,v 1.4 2003/10/05 00:09:04 pyromage Exp $
 *
 */

#include <cassert>
#include <iostream>

#include <signal.h>

#include "errormediator.h"
#include "exception.h"
#include "sighandler.h"

namespace emotion
{
	/* XXX: size? */
	const int NUMHANDLERS=32;
	static SignalHandler *_handlers[NUMHANDLERS];
	static void signal_handler (int sig);

	void register_handler (int sig, SignalHandler *h)
	{
		if (_handlers[sig] && _handlers[sig] != h)
		{
			ErrorMediator::instance()->submitError(
				Exception("signal congestion"));
			return;
		}

		_handlers[sig] = h;
		signal (sig, signal_handler);
	}

	void unregister_handler (SignalHandler *h)
	{
		for (int i=0; i<NUMHANDLERS; i++)
			if (_handlers[i] == h)
			{
				_handlers[i] = NULL;
				signal (i, SIG_DFL);
			}
	}

	static void signal_handler (int sig)
	{
		assert (_handlers[sig] != NULL);

		_handlers[sig]->handleSignal (sig);
	}
}
